import setuptools
VERSION='0.0.6'
setuptools.setup(
	name='stsutility',
	version=VERSION,
	author='636',
	author_email='win.stitch.23@gmail.com',
	description='636 Utility Package',
	url='https://github.com/0187773933/stsutility',
	packages=setuptools.find_packages(),
	classifiers=[
		'Programming Language :: Python :: 3',
		'License :: OSI Approved :: MIT License',
	    'Operating System :: OS Independent',
	],
	python_requires='>=3.6',
	setup_requires=['numpy','pandas','Pint'],
	install_requires=[
		'json',
		'pathlib',
		'time',
		'Pint',
		'math',
		'decimal',
		'operator',
		'pandas',
		'numpy',
		'pprint',
	],
)




import math
from decimal import Decimal
from decimal import getcontext
import pint
import numpy as np
import pandas as pd
import operator
from pprint import pprint
units = pint.UnitRegistry()

# https://colab.research.google.com/drive/1embO7TP1xdfOuG4saScgP4hbWwa1st30#scrollTo=VOuCZ1Z5yi-9
def divide( numerator , denominator , precision ):
    return Decimal( numerator / denominator ).quantize( Decimal( f'0.{"1".zfill( precision )}' ) )

def test():
	print( divide( float( 3.3 ) , 5 , 7 ) )